﻿using System;
using System.Windows;
using IgOutlook.Infrastructure.Ribbon;
using Microsoft.Practices.Prism.Regions;

namespace IgOutlook.Infrastructure.Prism
{
    public static class XamRibbonRegionExtensions
    {
        public static void ShowRibbonTab(this IRegion region, Object view)
        {
            if (region == null) throw new ArgumentNullException("region");
            if (view == null) throw new ArgumentNullException("view");
            ChangeViewVisibility(region, view, Visibility.Visible);
        }

        public static void HideRibbonTab(this IRegion region, Object view)
        {
            if (region == null) throw new ArgumentNullException("region");
            if (view == null) throw new ArgumentNullException("view");
            ChangeViewVisibility(region, view, Visibility.Collapsed);
        }

        /// <summary>
        /// Changes the view visibility and selects the default RibbonTabItem.
        /// </summary>
        /// <param name="region">The region.</param>
        /// <param name="view">The view.</param>
        /// <param name="visibility">The visibility.</param>
        static void ChangeViewVisibility(IRegion region, Object view, Visibility visibility)
        {

            var item = view as IRibbonTabItem;
            if (item == null)
                throw new ArgumentOutOfRangeException("view", "View must be an IRibbonTabItem");

            item.Visibility = visibility;
            region.Activate(view);
        }
    }
}
